#!/usr/bin/env Rscript       
#source("~/git/LSHTM_analysis/config/alr.R")
source("~/git/LSHTM_analysis/config/embb.R")
#source("~/git/LSHTM_analysis/config/katg.R")
#source("~/git/LSHTM_analysis/config/gid.R")
#source("~/git/LSHTM_analysis/config/pnca.R")
#source("~/git/LSHTM_analysis/config/rpob.R")

# get plottting dfs 
source("~/git/LSHTM_analysis/scripts/plotting/get_plotting_dfs.R")
####################################################
#=======
# output
#=======
outdir_images = paste0("~/git/Writing/thesis/images/results/", tolower(gene), "/")

#=======
# Input
#=======
merged_df3 = as.data.frame(merged_df3)
corr_plotdf = corr_data_extract(merged_df3
                                , gene = gene
                                , drug = drug
                                , extract_scaled_cols = F)
colnames(corr_plotdf)
colnames(corr_df_m3_f)
corr_plotdf = corr_df_m3_f  # for downstream code
#================
# stability
#================
corr_ps_colnames = c("DUET"
                     , "FoldX"
                     , "DeepDDG"
                     , "Dynamut2"
                     , "MAF"             
                     , "Log(OR)"       
                     , "-Log(P)"
                     #, "ligand_distance"
                     , "dst_mode"
                     , drug)

corr_ps_colnames%in%colnames(corr_plotdf)
corr_df_ps = corr_plotdf[, corr_ps_colnames]
complete_obs_ps = nrow(corr_df_ps) - sum(is.na(corr_df_ps$`Log(OR)`))
cat("\nComplete muts for Conservation for", gene, ":", complete_obs_ps)

color_coln = which(colnames(corr_df_ps) == "dst_mode")
end = which(colnames(corr_df_ps) == drug)
ncol_omit = 2
corr_end = end-ncol_omit

#------------------------
# Output: stability corrP
#------------------------
corr_psP =  paste0(outdir_images
                          ,tolower(gene)
                          ,"_corr_stability.svg" )

cat("Corr plot stability with coloured dots:", corr_psP)
svg(corr_psP, width = 15, height = 15)

my_corr_pairs(corr_data_all = corr_df_ps
  , corr_cols = colnames(corr_df_ps[1:corr_end])
  , corr_method = "spearman" # other options: "pearson" or "kendall"
  , colour_categ_col = colnames(corr_df_ps[color_coln]) #"dst_mode"
  , categ_colour =  c("red", "blue")
  , density_show = F
  , hist_col = "coral4"
  , dot_size = 1.6
  , ats = 1.5
  , corr_lab_size = 3
  , corr_value_size = 1)

dev.off()
#####################################################
#DistCutOff = 10
#LigDist_colname  # = "ligand_distance" # from globals 
#ppi2Dist_colname  = "interface_dist"
#naDist_colname    = "TBC"
#####################################################

#================
# ligand affinity
#================
corr_lig_colnames = c("mCSM-lig"       
                      , "MAF"             
                      , "Log(OR)"       
                      , "-Log(P)"
                      , "Lig-Dist"
                      , "dst_mode"
                      , drug)

corr_lig_colnames%in%colnames(corr_plotdf)
corr_df_lig = corr_plotdf[, corr_lig_colnames]
corr_df_lig = corr_df_lig[corr_df_lig["Lig-Dist"]<DistCutOff,]
complete_obs_lig = nrow(corr_df_lig) - sum(is.na(corr_df_lig$`Log(OR)`))
cat("\nComplete muts for lig affinity for", gene, ":", complete_obs_lig)

color_coln = which(colnames(corr_df_lig) == "dst_mode")
end = which(colnames(corr_df_lig) == drug)
ncol_omit = 3  #omit dist col
corr_end = end-ncol_omit

#------------------------
# Output: ligand corrP
#------------------------
corr_ligP =  paste0(outdir_images
                   ,tolower(gene)
                   ,"_corr_lig.svg" )

cat("Corr plot affinity with coloured dots:", corr_ligP)
svg(corr_ligP, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_lig
              , corr_cols = colnames(corr_df_lig[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_lig[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size =3
              , corr_value_size = 1)
dev.off()
####################################################
#================
# ppi2 affinity
#================
corr_ppi2_colnames = c("mCSM-PPI2"
                       , "MAF"             
                       , "Log(OR)"       
                       , "-Log(P)"
                       , "PPI-Dist"  # "interface_dist"
                       , "dst_mode"
                       , drug)

corr_ppi2_colnames%in%colnames(corr_plotdf)
corr_df_ppi2 = corr_plotdf[, corr_ppi2_colnames]
corr_df_ppi2 = corr_df_ppi2[corr_df_ppi2["PPI-Dist"]<DistCutOff,]
complete_obs_ppi2 = nrow(corr_df_ppi2) - sum(is.na(corr_df_ppi2$`Log(OR)`))
cat("\nComplete muts for ppi2 affinity for", gene, ":", complete_obs_ppi2)

color_coln = which(colnames(corr_df_ppi2) == "dst_mode")
end = which(colnames(corr_df_ppi2) == drug)
ncol_omit = 3 #omit dist col
corr_end = end-ncol_omit

#------------------------
# Output: ppi2 corrP
#------------------------
corr_ppi2P =  paste0(outdir_images
                    ,tolower(gene)
                    ,"_corr_ppi2.svg" )

cat("Corr plot ppi2 with coloured dots:", corr_ppi2P)
svg(corr_ppi2P, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_ppi2
              , corr_cols = colnames(corr_df_ppi2[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_ppi2[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size = 3
              , corr_value_size = 1)

dev.off()

# FIXME: ADD distance
#==================
# mCSSM-NA affinity
#==================
#================
# NA affinity
#================
corr_na_colnames = c("mCSM-NA"
                     , "MAF"             
                     , "Log(OR)"       
                     , "-Log(P)"
                     , "NA-Dist"  # "interface_dist"
                     , "dst_mode"
                     , drug)

corr_na_colnames%in%colnames(corr_plotdf)
corr_df_na = corr_plotdf[, corr_na_colnames]
corr_df_na = corr_df_na[corr_df_na["NA-Dist"]<DistCutOff,]
complete_obs_na = nrow(corr_df_na) - sum(is.na(corr_df_na$`Log(OR)`))
cat("\nComplete muts for NA affinity for", gene, ":", complete_obs_na)

color_coln = which(colnames(corr_df_na) == "dst_mode")
end = which(colnames(corr_df_na) == drug)
ncol_omit = 3 #omit dist col
corr_end = end-ncol_omit

#------------------------
# Output: mCSM-NA corrP
#------------------------
corr_naP =  paste0(outdir_images
                   ,tolower(gene)
                   ,"_corr_na.svg" )

cat("Corr plot mCSM-NA with coloured dots:", corr_naP)
svg(corr_naP, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_na
              , corr_cols = colnames(corr_df_na[1:corr_end])
              , corr_method = "spearman" 
              , colour_categ_col = colnames(corr_df_na[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size = 2
              , ats = 1.5
              , corr_lab_size = 3
              , corr_value_size = 1)

dev.off()

####################################################
# CONSERVATION
corr_conservation_cols = c("ConSurf"
                           , "SNAP2"
                           , "PROVEAN"
                           , "MAF"             
                           , "Log(OR)"       
                           , "-Log(P)"
                           , "dst_mode"
                           , drug)

colnames(corr_plotdf)
corr_conservation_cols%in%colnames(corr_plotdf)
corr_df_cons = corr_plotdf[, corr_conservation_cols]
complete_obs_cons = nrow(corr_df_cons) - sum(is.na(corr_df_cons$`Log(OR)`))
cat("\nComplete muts for Conservation for", gene, ":", complete_obs_cons)

color_coln = which(colnames(corr_df_cons) == "dst_mode")
end = which(colnames(corr_df_cons) == drug)
ncol_omit = 2 
corr_end = end-ncol_omit

#---------------------------
# Output: Conservation corrP
#----------------------------
corr_consP =  paste0(outdir_images
                     ,tolower(gene)
                     ,"_corr_conservation.svg" )

cat("Corr plot conservation coloured dots:", corr_consP)
svg(corr_consP, width = 10, height = 10)

my_corr_pairs(corr_data_all = corr_df_cons
              , corr_cols = colnames(corr_df_cons[1:corr_end])
              , corr_method = "spearman" # other options: "pearson" or "kendall"
              , colour_categ_col = colnames(corr_df_cons[color_coln]) #"dst_mode"
              , categ_colour =  c("red", "blue")
              , density_show = F
              , hist_col = "coral4"
              , dot_size =1.1
              , ats = 1.5
              , corr_lab_size = 2.5
              , corr_value_size = 1)

dev.off()
